@@ -1,7 +1,7 @@
 package Mojolicious::Plugin::ServerInfo;
 use Mojo::Base 'Mojolicious::Plugin';
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 sub register {
   my ($self, $app) = @_;
@@ -155,7 +155,7 @@ th {
 </body>
 </html>
 
-__END__
+@@ serverinfo.pod
 
 =head1 NAME
 
